@@ -9,16 +9,13 @@ else
         #uninstalling puppet
         echo -e "\e[1;33mUninstalling puppet....Please wait....\e[0m"
 	sudo apt-get remove puppetserver -y
-        sudo apt-get autoremove puppetserver -y
+        sudo apt-get remove --auto-remove puppetserver -y
         sudo apt-get purge puppetserver -y
-        sudo apt-get autoremove --purge puppetserver -y
-	sudo rm -rf puppet7-release-focal.deb
+        sudo apt-get purge --auto-remove puppetserver -y
+        sudo rm -rf /usr/bin/puppet
+        sudo rm -rf puppet7-release-bionic.deb
         if ! [[ $(which puppet) && $(puppet --version) ]]; then
                 echo -e "\e[1;32mpuppet uninstalled successfully\e[0m"
         fi
 fi
 
-#sudo apt-get remove puppetserver -y
-#sudo apt-get autoremove puppetserver -y
-#sudo apt-get purge puppetserver -y
-#sudo apt-get autoremove --purge puppetserver -y
